aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorCrystalwarrior <varsash@gmail.com>2019-09-13 11:13:50 +0300
committerCrystalwarrior <varsash@gmail.com>2019-09-13 11:13:50 +0300
commit455e020b19bb1801304cedd08b2675fe4bb30605 (patch)
tree6ba3aa424407a760e007b1d1a7e68de645fce3e3 /include
parentba41b070a208af9393abebd721fb1488fbedee57 (diff)
Make log go downwards by default
Rename kill_music_on_object to objection_stop_music for readability Update blip rate (faster overall, more accurate to the trilogy) - based on AOV values Update default blip rate to be "once every two symbols"
Diffstat (limited to 'include')
-rw-r--r--include/aoapplication.h4
-rw-r--r--include/courtroom.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/include/courtroom.h b/include/courtroom.h
index a3c4736b..ed5199df 100644
--- a/include/courtroom.h
+++ b/include/courtroom.h
@@ -249,7 +249,7 @@ private:
bool message_is_centered = false;
int current_display_speed = 3;
- int message_display_speed[7] = {30, 40, 50, 60, 75, 100, 120};
+ int message_display_speed[7] = {10, 20, 30, 40, 50, 60, 75};
// This is for checking if the character should start talking again
// when an inline blue text ends.
diff --git a/include/aoapplication.h b/include/aoapplication.h
index 94508ff8..e6cb21d6 100644
--- a/include/aoapplication.h
+++ b/include/aoapplication.h
@@ -150,8 +150,8 @@ public:
//Returns true if blank blips is enabled in config.ini and false otherwise
bool get_blank_blip();
- //Returns true if kill music on object is enabled in the config.ini
- bool get_objectmusic();
+ //Returns true if stop music on objection is enabled in the config.ini
+ bool objection_stop_music();
//Returns the value of default_music in config.ini
int get_default_music();